@@ -231,7 +231,7 @@ void MainWindow::setupLayoutActions()
   actionEditBreakLayout->setWhatsThis(whatsThisFrom("Layout|Break Layout"));
   
   int id = WidgetDatabase::idFromClassName("Spacer");
-  KToggleAction *a = new KToggleAction("Spacer", KShortcut::null(), this, SLOT(toolSelected()), 
+  KToggleAction *a = new KToggleAction(i18n("Spacer"), createIconSet("spacer.xpm"), KShortcut::null(), this, SLOT(toolSelected()), 
                                        actionCollection(), QString::number(id).latin1());
   a->setExclusiveGroup("tool");
   a->setText(i18n("Add ") + WidgetDatabase::className(id));
@@ -562,6 +562,11 @@ void MainWindow::setupSettingsActions()
   a->setWhatsThis(whatsThisFrom("Edit|Preferences"));
   a->plug(settings);
 
+  a = new KAction(i18n("Configure &plugins..."), KShortcut::null(), this, SLOT(editPlugins()),
+    actionCollection(), "configure_plugins");
+  a->setToolTip(i18n("Opens a dialog to configure plugins"));
+  a->plug(settings);
+ 
   menuBar()->insertItem( i18n("&Settings"), settings);
 } 
 
@@ -1113,6 +1118,13 @@ void MainWindow::editShortcuts()
   KKeyDialog K(false);
   K.configure(actionCollection());
 }
+
+void MainWindow::editPlugins()
+{
+  KProcess process;
+  process << "kmdr-plugins";
+  process.start(KProcess::Block);
+}
     
 void MainWindow::editExternalTool(int id)
 {
