@@ -1085,7 +1085,7 @@ handler_routine(DWORD dwCtrlType)
             break;
     }
 
-    return (TRUE);
+    return (true);
 }
 
 #endif
@@ -1251,7 +1251,7 @@ if (xsldbgHasLineNumberFix){
         /* catch SIGINT */
         oldHandler = signal(SIGINT, catchSigInt);
 #else
-        if (SetConsoleCtrlHandler(handler_routine, TRUE) != TRUE)
+        if (SetConsoleCtrlHandler(handler_routine, true) != true)
             return result;
 #endif
 
@@ -1280,7 +1280,7 @@ xsldbgFree()
     if (oldHandler != SIG_ERR)
         signal(SIGINT, oldHandler);
 #else
-    SetConsoleCtrlHandler(handler_routine, FALSE);
+    SetConsoleCtrlHandler(handler_routine, false);
 #endif
     initialized = 0;
 
