@@ -28,11 +28,11 @@ class DebuggerUI;
 class DebuggerVariable;
 class DebuggerBreakpoint;
 class PathMapper;
+class Document;
 
 class DebuggerManager : public QObject
 {
     Q_OBJECT
-
   private:
     // client
     DebuggerClient *m_client;
@@ -44,6 +44,11 @@ class DebuggerManager : public QObject
     // Internal help functions
     void initActions();
     void initClientActions();
+    void saveProperties();
+    
+    void connectBreakpointSignals(Document*);
+    void disconnectBreakpointSignals(Document*);
+
     QString m_currentFile;
     long m_currentLine;
 
@@ -60,7 +65,9 @@ class DebuggerManager : public QObject
     void haveBreakpoint (const QString& file, int line);
     void havenoBreakpoint (const QString& file, int line);
     void refreshBreakpoints();
-    DebuggerBreakpoint *newDebuggerBreakpoint();
+//     DebuggerBreakpoint *newDebuggerBreakpoint();
+    DebuggerBreakpoint * findDebuggerBreakpoint(const QString& key);
+    void updateBreakpointKey(const DebuggerBreakpoint &bp, const QString& newkey);
 
     // Public help functions
     bool showStatus(const QString& message, bool log);
@@ -73,10 +80,11 @@ class DebuggerManager : public QObject
     bool hasClient() { return m_client != 0; };
 
   public slots:
-    /** Execution control slots **/
+
+    // Execution control slots
     void slotDebugRequest();
     void slotDebugRun();
-    void slotDebugLeap();
+    void slotDebugTrace();
     void slotDebugSkip();
     void slotDebugStepOver();
     void slotDebugStepInto();
@@ -99,9 +107,19 @@ class DebuggerManager : public QObject
     void slotDebugStartSession();
     void slotDebugEndSession();
 
+    // Profiler
+    void slotProfilerOpen();
+
     // Initiation
     void slotNewProjectLoaded(const QString &, const KURL &, const KURL &);
 
+    // Event handling
+    void slotHandleEvent(const QString &, const QString &, const QString &);
+        
+  private slots:
+    void slotBreakpointMarked(Document*, int);
+    void slotBreakpointUnmarked(Document*, int);
+
   signals:
     void hideSplash();
 };
