@@ -43,8 +43,11 @@
 #include "quantacommon.h"
 #include "document.h"
 #include "qextfileinfo.h"
+
+
 #include "kafkacommon.h"
 #include "undoredo.h"
+
 #include "dtds.h"
 #include "structtreetag.h"
 
@@ -64,6 +67,8 @@
 extern GroupElementMapList globalGroupMap;
 static const QChar space(' ');
 
+extern int NN;
+
 Parser::Parser()
 {
   m_node = 0L;
@@ -457,7 +462,7 @@ Node *Parser::parseArea(int startLine, int startCol, int endLine, int endCol, No
         ec = 0;
     AreaStruct area(el, ec, endLine, endCol);
 #ifdef DEBUG_PARSER
-    kdDebug(24000) << "Calling cleanGroups from Parser::parseArea" << endl;
+//     kdDebug(24000) << "Calling cleanGroups from Parser::parseArea" << endl;
 #endif
     cleanGroups();
     m_saParser->setParsingEnabled(true);
@@ -515,10 +520,14 @@ Node *Parser::parse(Document *w, bool force)
  // clearGroups();
   if (baseNode)
   {
-    delete baseNode;
-    baseNode = 0L;
-    m_node = 0L;
+     kdDebug(24000) << "NN before delete = " << NN << endl;
+     //kdDebug(24000) << "baseNode before delete = " << baseNode << endl;
+     //ParserCommon::coutTree(m_node, 2);
+     delete baseNode;
+     baseNode = 0L;
+     kdDebug(24000) << "NN after delete = " << NN << endl;
   }
+  m_node = 0L;
 
   Node *lastNode;
   write = w;
@@ -543,6 +552,7 @@ Node *Parser::parse(Document *w, bool force)
 
 //FIXME: What is the use of two pointer to the same Node???
  baseNode = m_node;
+     kdDebug(24000) << "NN after parse = " << NN << "baseNode : " << baseNode << endl;
  m_saParser->init(m_node, w);
 
  //We need to reload Kafka to refresh the DOM::Node->Node links.
@@ -657,6 +667,7 @@ Node *Parser::nodeAt(int line, int col, bool findDeepest, bool exact)
 }
 void Parser::logReparse(NodeModifsSet *modifs, Document *w)
 {
+
   NodeModif *modif;
   if (baseNode)
   {
@@ -796,6 +807,7 @@ void Parser::deleteNodes(Node *firstNode, Node *lastNode, NodeModifsSet *modifs)
   Node *node = firstNode;
   bool closesPrevious = false;
   NodeModif *modif;
+
   //delete all the nodes between the firstNode and lastNode
   while (node && node != lastNode )
   {
@@ -829,8 +841,11 @@ void Parser::deleteNodes(Node *firstNode, Node *lastNode, NodeModifsSet *modifs)
     node->parent = 0L;
     node->next = 0L;
     node->prev = 0L;
+    
+    //delete node;
     node->detachNode();
     modif->setNode(node);
+
     node = 0L;
     i = 0;
     j = 0;
@@ -936,9 +951,11 @@ void Parser::deleteNodes(Node *firstNode, Node *lastNode, NodeModifsSet *modifs)
 
       }
     }
+
     modif->setChildrenMovedUp(i);
     modif->setNeighboursMovedDown(j);
     modifs->addNodeModif(modif);
+
     node = nextNode;
 
  //   kdDebug(24000)<< "Node removed!" << endl;
@@ -961,7 +978,6 @@ Node *Parser::rebuild(Document *w)
  NodeModifsSet *modifs = new NodeModifsSet();
  NodeModif *modif;
 
-
 // kdDebug(24000)<< "Node *Parser::rebuild()" << endl;
  modifs->setIsModifiedAfter(w->isModified());
 
@@ -989,9 +1005,10 @@ Node *Parser::rebuild(Document *w)
         (area.eLine < area.bLine || (area.eLine == area.bLine && area.eCol <= area.bCol)) //something strange has happened, like moving text with D&D inside the editor
       )
    {
-     logReparse(modifs, w);
-     m_saParser->setParsingEnabled(saParserEnabled);
-     return parse(w);
+      logReparse(modifs, w);
+       m_saParser->setParsingEnabled(saParserEnabled);
+       Node *n = parse(w, true);
+       return n;
    }
 
    kdDebug(24000) << QString("Invalid area: %1,%2,%3,%4").arg(area.bLine).arg(area.bCol).arg(area.eLine).arg(area.eCol) << "\n";
@@ -1071,6 +1088,7 @@ Node *Parser::rebuild(Document *w)
         modif = new NodeModif();
         modif->setType(NodeModif::NodeRemoved);
         modif->setLocation(kafkaCommon::getLocation(lastNode));
+
         if(lastInserted->prev)
           lastInserted->prev->next = 0L;
         if(lastInserted->parent && lastInserted->parent->child == lastInserted)
@@ -1079,6 +1097,8 @@ Node *Parser::rebuild(Document *w)
         lastInserted->next = 0L;
         lastInserted->parent = 0L;
         lastInserted->child = 0L;
+//        delete lastInserted;
+
         lastInserted->detachNode();
         modif->setNode(lastInserted);
         modifs->addNodeModif(modif);
@@ -1185,9 +1205,10 @@ Node *Parser::rebuild(Document *w)
 /*   kdDebug(24000)<< "END"<< endl;
    ParserCommon::coutTree(baseNode,  2);
    kdDebug(24000)<< "************* End User Modification *****************" << endl;*/
+
    w->docUndoRedo->addNewModifsSet(modifs, undoRedo::SourceModif);
  }
-  kdDebug(24000) << "Rebuild: " << t.elapsed() << " ms \n";
+  kdDebug(24000) << "Rebuild: " << t.elapsed() << " ms; baseNode=" << baseNode << "\n";
 
 /* treeSize = 0;
  ParserCommon::coutTree(m_node, 2);
@@ -1204,7 +1225,7 @@ Node *Parser::rebuild(Document *w)
 void Parser::clearGroups()
 {
 #ifdef DEBUG_PARSER
-  kdDebug(24000) << "clearGroups " << endl;
+//   kdDebug(24000) << "clearGroups " << endl;
 #endif
   GroupElementMapList::Iterator it;
   GroupElementList::Iterator elementIt;
@@ -1239,7 +1260,7 @@ void Parser::clearGroups()
     }
   }
 #ifdef DEBUG_PARSER
-      kdDebug(24000) << count << " GroupElement deleted (clearGroups)." << endl;
+//       kdDebug(24000) << count << " GroupElement deleted (clearGroups)." << endl;
 #endif
   globalGroupMap.clear();
   clearIncludedGroupElements();
@@ -1255,7 +1276,7 @@ void Parser::clearGroups()
 void Parser::cleanGroups()
 {
 #ifdef DEBUG_PARSER
-  kdDebug(24000) << "cleanGroups " << endl;
+//   kdDebug(24000) << "cleanGroups " << endl;
 #endif
   GroupElementMapList::Iterator it;
   GroupElementList::Iterator elementIt;
@@ -1290,7 +1311,7 @@ void Parser::cleanGroups()
     }
   }
 #ifdef DEBUG_PARSER
-      kdDebug(24000) << count << "GroupElement deleted (cleanGroups)." << endl;
+//       kdDebug(24000) << count << " GroupElement deleted (cleanGroups)." << endl;
 #endif
   if (m_parseIncludedFiles)
   {
